// command.h - John K. Estell - 1 February 2002
// command parser interface.  When a Command object is instantiated,
// the passed string is parsed into <verb, noun> format, which is defined
// as: first word is a verb or a direction, and all remaining words comprise
// the noun.  

#ifndef COMMAND_H
#define COMMAND_H

#include <string>
using namespace std;

// enumerated data types - used to indicate the supported directions and verbs
// for the program.  Supported nouns (other than directions) are obtained from
// the item data file.  The 'Unknown' values are used when there's no match.
enum direction { North, South, East, West, Up, Down, UnknownDirection };
enum verb { Move, Look, Score, Quit, Take, Drop, Inventory, Help, UnknownVerb };

class Command {
	public:
		Command( string input );
		verb getVerb();
		string getNoun();
		direction getDirection();
	private:
		verb commandVerb;			// store for the selected action
		string commandNoun;			// store for the noun
		direction commandDirection;	// store for the direction of travel (as appropriate)
};


// auxiliary functions
verb parseVerb( string verbString );
direction parseDirection( string directionString );

#endif